/*
 * Copyright (c) 2021 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __ANNOUNCE_H
#define __ANNOUNCE_H

#include <jeffpc/uuid.h>

enum announce_msg_type {
	ANNOUNCE_QSO_NEW = 0x10,
	ANNOUNCE_QSO_UPDATED,
	ANNOUNCE_LOC_CURRENT = 0x20,
	ANNOUNCE_LOC_ACQ,
	ANNOUNCE_LOC_CHANGE,
	ANNOUNCE_LOC_LOST,
	ANNOUNCE_LOC_DISCONNECT, /* location device disconnected */
};

struct announce_msg {
	uint32_t type;
	uint32_t _pad0;

	union {
		struct {
			uint8_t uuid[16];
		} qso; /* ANNOUNCE_QSO_* */
		struct {
			uint8_t mode; /* 0 = no fix, 2 = 2D, 3 = 3D */
			uint8_t grid[9]; /* nul terminated */
			uint8_t _pad1[6];
		} loc; /* ANNOUNCE_LOC_* */
	} u;
} __attribute__((packed));
STATIC_ASSERT(sizeof(struct announce_msg) == 24);

extern int announce_start(void);
extern void announce_notify_qso(enum announce_msg_type type,
				const struct xuuid *uuid);
extern void announce_notify_loc(enum announce_msg_type type,
				uint8_t mode, char *grid);

extern void announce_stop(void);

#endif
